@@ -10,6 +10,8 @@
 #    NOTES
 #
 #    MODIFIED   (MM/DD/YY)
+#    paboyoun    09/17/12 - add difftime support
+#    demukhin    09/11/12 - add Extproc driver
 #    jfeldhau    06/19/12 - ROracle support for TimesTen.
 #    rpingte     04/25/12 - use externalptr for connection and result set
 #    rpingte     04/23/12 - add interrupt enable to driver
@@ -29,33 +31,79 @@ setClass("OraDriver",
   contains = "DBIDriver"
 )
 
-Oracle <- function(interruptible = FALSE) .oci.Driver(interruptible)
+Oracle <- function(interruptible = FALSE)
+{
+  .oci.Driver(.oci.drv(), interruptible = interruptible)
+}
 
 setMethod("dbUnloadDriver",
 signature(drv = "OraDriver"),
-function(drv, ...) .oci.UnloadDriver()
+function(drv, ...) .oci.UnloadDriver(.oci.drv())
 )
 
 setMethod("dbListConnections",
 signature(drv = "OraDriver"),
-function(drv, ...) .oci.DriverInfo("connections")[[1L]]
+function(drv, ...) .oci.DriverInfo(.oci.drv(), "connections")[[1L]]
 )
 
 setMethod("dbGetInfo",
 signature(dbObj = "OraDriver"),
-function(dbObj, ...) .oci.DriverInfo(...)
+function(dbObj, ...) .oci.DriverInfo(.oci.drv(), ...)
 )
 
 setMethod("summary",
 signature(object = "OraDriver"),
-function(object, ...) .oci.DriverSummary()
+function(object, ...) .oci.DriverSummary(.oci.drv())
 )
 
 setMethod("show",
 signature(object = "OraDriver"),
 function (object)
 {
-  .oci.DriverSummary()
+  .oci.DriverSummary(.oci.drv())
+  invisible()
+}
+)
+
+##
+## Class: DBIDriver
+##
+setClass("ExtDriver",
+  representation(
+    handle = "externalptr"),
+  contains = "DBIDriver"
+)
+
+Extproc <- function(extproc.ctx = NULL)
+{
+  .oci.Driver(.ext.drv(), extproc.ctx = extproc.ctx)
+}
+
+setMethod("dbUnloadDriver",
+signature(drv = "ExtDriver"),
+function(drv, ...) .oci.UnloadDriver(.ext.drv())
+)
+
+setMethod("dbListConnections",
+signature(drv = "ExtDriver"),
+function(drv, ...) .oci.DriverInfo(.ext.drv(), "connections")[[1L]]
+)
+
+setMethod("dbGetInfo",
+signature(dbObj = "ExtDriver"),
+function(dbObj, ...) .oci.DriverInfo(.ext.drv(), ...)
+)
+
+setMethod("summary",
+signature(object = "ExtDriver"),
+function(object, ...) .oci.DriverSummary(.ext.drv())
+)
+
+setMethod("show",
+signature(object = "ExtDriver"),
+function (object)
+{
+  .oci.DriverSummary(.ext.drv())
   invisible()
 }
 )
@@ -72,7 +120,18 @@ setClass("OraConnection",
 
 setMethod("dbConnect",
 signature(drv = "OraDriver"),
-function(drv, ...) .oci.Connect(...)
+function(drv, username = "", password = "", dbname = "", prefetch = FALSE,
+         bulk_read = 25L, stmt_cache = 0L, ...)
+.oci.Connect(.oci.drv(), username = username, password = password,
+             dbname = dbname, prefetch = prefetch, bulk_read = bulk_read,
+             stmt_cache = stmt_cache)
+)
+
+setMethod("dbConnect",
+signature(drv = "ExtDriver"),
+function(drv, prefetch = FALSE, bulk_read = 25L, stmt_cache = 0L, ...)
+.oci.Connect(.ext.drv(), prefetch = prefetch, bulk_read = bulk_read,
+             stmt_cache = stmt_cache)
 )
 
 setMethod("dbDisconnect",
@@ -82,12 +141,16 @@ function(conn, ...) .oci.Disconnect(conn)
 
 setMethod("dbSendQuery",
 signature(conn = "OraConnection", statement = "character"),
-function(conn, statement, ...) .oci.SendQuery(conn, statement, ...)
+function(conn, statement, data = NULL, prefetch = FALSE, bulk_read = 25L, ...)
+.oci.SendQuery(conn, statement, data = data, prefetch = prefetch,
+               bulk_read = bulk_read)
 )
 
 setMethod("dbGetQuery",
 signature(conn = "OraConnection", statement = "character"),
-function(conn, statement, ...) .oci.GetQuery(conn, statement, ...)
+function(conn, statement, data = NULL, prefetch = FALSE, bulk_read = 25L, ...)
+.oci.GetQuery(conn, statement, data = data, prefetch = prefetch,
+              bulk_read = bulk_read)
 )
 
 setMethod("dbGetException",
@@ -102,7 +165,13 @@ function(conn, ...) .oci.ConnectionInfo(conn, "results")[[1L]]
 
 setMethod("dbGetInfo",
 signature(dbObj = "OraConnection"),
-function(dbObj, ...) .oci.ConnectionInfo(dbObj, ...)
+function(dbObj, what, ...)
+{
+  if (missing(what))
+    .oci.ConnectionInfo(dbObj)
+  else
+    .oci.ConnectionInfo(dbObj, what = what)
+}
 )
 
 setMethod("summary",
@@ -124,32 +193,41 @@ function (object)
 ##
 setMethod("dbListTables",
 signature(conn = "OraConnection"),
-function(conn, ...) .oci.ListTables(conn, ...)
+function(conn, schema = NULL, all = FALSE, full = FALSE, ...)
+.oci.ListTables(conn, schema = schema, all = all, full = full)
 )
 
 setMethod("dbReadTable",
 signature(conn = "OraConnection", name = "character"),
-function(conn, name, ...) .oci.ReadTable(conn, name, ...)
+function(conn, name, schema = NULL, row.names = NULL, ...)
+.oci.ReadTable(conn, name, schema = schema, row.names = row.names)
 )
 
 setMethod("dbWriteTable",
 signature(conn = "OraConnection", name = "character", value = "data.frame"),
-function(conn, name, value, ...) .oci.WriteTable(conn, name, value, ...)
+function(conn, name, value, row.names = FALSE, overwrite = FALSE,
+         append = FALSE, ora.number = TRUE, ...)
+.oci.WriteTable(conn, name, value, row.names = row.names,
+                overwrite = overwrite, append = append,
+                ora.number = ora.number)
 )
 
 setMethod("dbExistsTable",
 signature(conn = "OraConnection", name = "character"),
-function(conn, name, ...) .oci.ExistsTable(conn, name, ...)
+function(conn, name, schema = NULL, ...)
+.oci.ExistsTable(conn, name, schema = schema)
 )
 
 setMethod("dbRemoveTable",
 signature(conn = "OraConnection", name = "character"),
-function(conn, name, ...) .oci.RemoveTable(conn, name, ...)
+function(conn, name, purge = FALSE, ...)
+.oci.RemoveTable(conn, name, purge = purge)
 )
 
 setMethod("dbListFields",
 signature(conn = "OraConnection", name = "character"),
-function(conn, name, ...) .oci.ListFields(conn, name, ...)
+function(conn, name, schema = NULL, ...)
+.oci.ListFields(conn, name, schema = schema)
 )
 
 ##
@@ -183,13 +261,8 @@ setClass("OraResult",
 )
 
 setMethod("fetch",
-signature(res = "OraResult", n = "numeric"),
-function(res, n, ...) .oci.fetch(res, as.integer(n))
-)
-
-setMethod("fetch",
-signature(res = "OraResult", n = "missing"),
-function(res, n, ...) .oci.fetch(res)
+signature(res = "OraResult"),
+function(res, n = -1, ...) .oci.fetch(res, as.integer(n))
 )
 
 setMethod("dbClearResult",
@@ -224,7 +297,13 @@ function(res, ...) .oci.ResultInfo(res, "rowCount")[[1L]]
 
 setMethod("dbGetInfo",
 signature(dbObj = "OraResult"),
-function(dbObj, ...) .oci.ResultInfo(dbObj, ...)
+function(dbObj, what, ...)
+{
+  if (missing(what))
+    .oci.ResultInfo(dbObj)
+  else
+    .oci.ResultInfo(dbObj, what = what)
+}
 )
 
 setMethod("summary",
@@ -258,5 +337,5 @@ function(res, ...) standardGeneric("execute")
 
 setMethod("execute",
 signature(res = "OraResult"),
-function(res, ...) .oci.execute(res, ...)
+function(res, data = NULL, ...) .oci.execute(res, data = data)
 )
